==> haskell-rsa-2.4.1-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-DrOYsdNDcCIKSuPtv9pB2D
key:                  RSA-2.4.1-DrOYsdNDcCIKSuPtv9pB2D
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  5ccc0e74daaa581f6edb0aff61f3f46d
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-9.0.1/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/RSA-2.4.1
hs-libraries:         HSRSA-2.4.1-DrOYsdNDcCIKSuPtv9pB2D
depends:
    SHA-1.6.4.4-7e0sYz0lBWb1CdwjpynTkG base-4.15.0.0 binary-0.8.8.0
    bytestring-0.10.12.1 crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    crypto-pubkey-types-0.4.3-Acnacid1uvj9ycLSIZdbsB

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.4.1-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-2MO3LC1WkhbCrbxPq0mQek
key:                  RSA-2.4.1-2MO3LC1WkhbCrbxPq0mQek
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  91bc18a7f22a7ec115e294b7dd1c9e00
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-9.0.1/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/RSA-2.4.1
hs-libraries:         HSRSA-2.4.1-2MO3LC1WkhbCrbxPq0mQek
depends:
    SHA-1.6.4.4-7e0sYz0lBWb1CdwjpynTkG base-4.15.0.0 binary-0.8.8.0
    bytestring-0.10.12.1 crypto-api-0.13.3-K4D4TqlwTtyDpSHz3hLF4b
    crypto-pubkey-types-0.4.3-1d6p6WhaBtDDmsYF6rxPCZ

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
